@@ -452,10 +452,10 @@ mi.check.correlation <- function ( data, threshhold = 0.99999 ){
 
 mi.correlated.list <- function ( data, threshhold = 0.99999 ){
   options(warn = -1)
-  cor.data<-cor( data, use="pairwise.complete.obs" )
+  cor.data <- cor( data, use="pairwise.complete.obs" )
   diag(cor.data)<-1
-  index<-abs( cor.data - diag(dim(cor.data)[1])) >= threshhold 
-  result<-vector("list",dim(index)[1])
+  index <- abs( cor.data - diag(dim(cor.data)[1])) >= threshhold 
+  result <- vector("list",dim(index)[1])
   for( i in 1:dim(index)[1] ){
     if(length(names(which(index[i,]==1)))>0){
       result[[i]]<-c(names(data)[i],names(which(index[i,]==1)))
@@ -466,9 +466,18 @@ mi.correlated.list <- function ( data, threshhold = 0.99999 ){
       result[[i]]<-NA
     }
   }
-  unique.cor<-unique(result)
-  unique.cor<- unique.cor[!sapply(unique.cor,is.null)] 
-  unique.cor<- unique.cor[!sapply(sapply(unique.cor,is.na),any)]
+  unique.cor <- unique(result)
+  unique.cor <- unique.cor[!sapply(unique.cor,is.null)] 
+  unique.cor <- unique.cor[!sapply(sapply(unique.cor,is.na),any)]
+  if(length(unique.cor)>0){
+    for(k in 1:length(unique.cor)){
+      chk <- is.na(data[,unique.cor[[k]][1]]) -  is.na(data[,unique.cor[[k]][2]])
+      if(!all(chk==0)){
+        unique.cor[[k]] <- NA
+      }
+    }
+    unique.cor <- unique.cor[!sapply(sapply(unique.cor,is.na),any)]
+  }
   options(warn = 0)
   return(unique.cor)
 }
