@@ -51,7 +51,7 @@ mi.polr <- function ( formula, data = NULL, drop.unused.levels = TRUE,
                               drop.unused.levels = FALSE, n.iter = n.iter )
   expect.prob <- predict( bplr.imp, newdata = data, type = "probs" )
   determ.pred <- predict(bplr.imp, newdata=data, type="class")#as.vector( expect.prob %*% as.double( Y.levels ) )
-#  names( determ.pred ) <- 1:length( determ.pred )
+  names( determ.pred ) <- 1:length( determ.pred )
   if(n.mis>0){
     random.pred <- Rmultnm(n.mis, expect.prob[mis,], 1:Y.nlevel)    
     random.pred <-  recode(random.pred, paste(1:Y.nlevel,"='",Y.levels,"'",sep="",collapse=";") )        
